@@ -2,9 +2,9 @@
 #' @description This function allows you to download a database selected by
 #' \code{\link{listDatabases}} to your local hard drive.
 #' @param name a character string specifying the database that shall be downloaded (selected from \code{\link{listDatabases}}).
-#' @param db_format a character string specifying database format, e.g. \code{db_format} = \code{"blastdb"}.
+#' @param db_format a character string specifying database format, e.g. \code{db_format} = \code{"blastdb"} or \code{db_format} = \code{"fasta"}.
 #' @param path a character string specifying the location (a folder) in which the corresponding
-#' database shall be stored. Default is \code{path} = \code{"DB"}.
+#' database shall be stored. Default is \code{path} = \code{"DB"}. In case this folder does not exist yet, it will be created.
 #' @details
 #' This function downloads large databases to your hard drive. For this purpose a folder
 #' named \code{DB} (default) is created and the correspondning database then stored in this folder. 
@@ -26,13 +26,19 @@
 
 download_database <- function(name, db_format = "blastdb", path = "DB"){
         
-        if(!is.element(db_format,c("blastdb","fasta")))
+        if (!is.element(db_format,c("blastdb","fasta")))
                 stop("db_format = '",db_format,"' is not supported by this function.")
         
-        if(!file.exists(path))
+        if (!file.exists(path))
                 dir.create(path)
         
-        downloader::download(paste0("ftp://ftp.ncbi.nlm.nih.gov/blast/db/",name), file.path(path,name) , mode = "wb")
+        if (db_format == "blastdb"){
+                downloader::download(paste0("ftp://ftp.ncbi.nlm.nih.gov/blast/db/",name), file.path(path,name) , mode = "wb")
+        }
+        
+        if (db_format == "fasta"){
+                downloader::download(paste0("ftp://ftp.ncbi.nlm.nih.gov/blast/db/FASTA/",name), file.path(path,name) , mode = "wb")
+        }
         
         # limit NCBI queries
         Sys.sleep(0.33)
