@@ -6,18 +6,16 @@
 #' @param dataset a character string specifying the dataset for which filters shall be listed.
 #' @author Hajk-Georg Drost
 #' @examples
-#' 
-#' # search for available datasets
-#' head(getMarts(), 10)
-#' 
 #' \dontrun{
+#' # search for available datasets
+#' getMarts()
 #' 
-#' # choose database (mart): "plants_mart_25" -> Note: mart versions change over time
-#' # and get a table of all available datasets from this BioMart database
-#' head(getDatasets(mart = "plants_mart_25"), 10)
 #' 
-#' # choose dataset: "athaliana_eg_gene"
-#' head(getFilters(mart = "plants_mart_25", dataset = "athaliana_eg_gene") , 5)
+#' # choose database (mart): "ENSEMBL_MART_ENSEMBL"
+#' head(getDatasets(mart = "ENSEMBL_MART_ENSEMBL"), 10)
+#' 
+#' # choose dataset: "hsapiens_gene_ensembl"
+#' head(getFilters(mart = "ENSEMBL_MART_ENSEMBL", dataset = "hsapiens_gene_ensembl") , 5)
 #' 
 #' }
 #' 
@@ -28,7 +26,7 @@ getFilters <- function(mart, dataset){
         if((!is.character(mart)) || (!is.character(dataset)))
                 stop("Please use a character string as mart or dataset.")
         
-        url <- paste0("http://www.biomart.org/biomart/martservice?type=filters&dataset=",dataset,"&requestid=biomart&mart=",mart,"&virtualSchema=default")
+        url <- paste0("http://www.ensembl.org/biomart/martservice?type=filters&dataset=",dataset,"&requestid=biomart&mart=",mart,"&virtualSchema=default")
         
         filterPage <- httr::handle(url)
         xmlContentFilters <- httr::GET(handle = filterPage)
