@@ -70,20 +70,24 @@ listDatabases <- function(db_name = "nr", db_format = "fasta", update = FALSE){
                         listDBs <- listDBs[[1]]
                 }
                 
-                # select all database versions of 'db_name'
-                DBName <- listDBs[sapply(listDBs,function(x) stringr::str_detect(x,paste0("^",db_name)))]
-                
-                if(length(DBName) == 0)
-                        stop("No entries for db_name = '",db_name,"' could not be found.")
-                
-                # limit NCBI queries
-                if(!file.exists(file.path(tempdir(),"_ncbi_downloads","listDatabases.txt")))
-                        Sys.sleep(0.33)
-                
-                # delete md5 entries
-                return(DBName[-which(sapply(DBName,function(x) stringr::str_detect(x,".md5")))])
-                
+                if (db_name == "all"){
+                        return(listDBs[-which(sapply(listDBs,function(x) stringr::str_detect(x,".md5")))])
+                } else {
+                        
+                        # select all database versions of 'db_name'
+                        DBName <- listDBs[sapply(listDBs,function(x) stringr::str_detect(x,paste0("^",db_name)))]
+                        
+                        if(length(DBName) == 0)
+                                stop("No entries for db_name = '",db_name,"' could not be found.")
+                        
+                        # limit NCBI queries
+                        if(!file.exists(file.path(tempdir(),"_ncbi_downloads","listDatabases.txt")))
+                                Sys.sleep(0.33)
+                        
+                        # delete md5 entries
+                        return(DBName[-which(sapply(DBName,function(x) stringr::str_detect(x,".md5")))])
+                        
+                }
         }
-        
 }
 
